@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3
-id: authenticate-1.3.3-e1786589aa33ebec7643f5494d2d4c58
-key: authe_F6xW5EBe6TgIOW0ZXVy6U2
+id: authenticate-1.3.3-8bfd9d9af351074d4824dfaf64857f58
+key: authe_DvMOSDNjynND2oIE9fy4RA
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,26 +23,26 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-F6xW5EBe6TgIOW0ZXVy6U2
+hs-libraries: HSauthenticate-1.3.3-DvMOSDNjynND2oIE9fy4RA
 depends:
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
     attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
-    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
+    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.8-e2c4d8f7b8297fdf1ac5b7f32d06d5dd
+    http-conduit-2.1.8-b9e39b39a9098cc832013cbf6ff75355
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
-    tagstream-conduit-0.5.5.3-ee2c4f50b9808fab97ea27c2a34b3894
+    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
+    tagstream-conduit-0.5.5.3-5116d743e8946a7a525b2d26c8dd3698
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
-    xml-conduit-1.3.3.1-40ad40c80af811edb9755c807c4ab5cc
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    xml-conduit-1.3.3.1-daddc82b56f1f7b1ac0bd9d16f4322ab
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
